==> darkradiant_2.0.4.orig.tar.gz: DarkRadiant-2.0.4/plugins/entity/target/TargetLineNode.cpp <==
#include "TargetLineNode.h"

#include "../EntityNode.h"

namespace entity
{

TargetLineNode::TargetLineNode(EntityNode& owner) :
    scene::Node(),
    _owner(owner),
    _targetLines(_owner.getTargetKeys())
{}

TargetLineNode::TargetLineNode(TargetLineNode& other) :
    scene::Node(other),
    _owner(other._owner),
    _targetLines(_owner.getTargetKeys())
{}

scene::INode::Type TargetLineNode::getNodeType() const
{
    return Type::EntityConnection;
}

const AABB& TargetLineNode::localAABB() const
{
    return _aabb;
}

void TargetLineNode::renderSolid(RenderableCollector& collector, const VolumeTest& volume) const
{
    renderWireframe(collector, volume);
}

void TargetLineNode::renderWireframe(RenderableCollector& collector, const VolumeTest& volume) const
{
    // If the owner is hidden, the lines are hidden too
    if (!_targetLines.hasTargets() || !_owner.visible()) return;

    collector.SetState(_owner.getWireShader(), RenderableCollector::eWireframeOnly);
	collector.SetState(_owner.getWireShader(), RenderableCollector::eFullMaterials);

	_targetLines.render(collector, volume, getOwnerPosition());
}

bool TargetLineNode::isHighlighted() const
{
    // We don't need to return true, since the render system will use 
    // the result of the parent entity node
    return false;
}

const Vector3& TargetLineNode::getOwnerPosition() const
{
	const AABB& bounds = _owner.worldAABB();

	if (bounds.isValid())
    {
		return bounds.getOrigin();
	}

	return _owner.localToWorld().t().getVector3();
}

}

==> darkradiant_2.1.0.orig.tar.gz: DarkRadiant-2.1.0/plugins/entity/target/TargetLineNode.cpp <==
#include "TargetLineNode.h"

#include "../EntityNode.h"

namespace entity
{

TargetLineNode::TargetLineNode(EntityNode& owner) :
    scene::Node(),
    _owner(owner),
    _targetLines(_owner.getTargetKeys())
{}

TargetLineNode::TargetLineNode(TargetLineNode& other) :
    scene::Node(other),
    _owner(other._owner),
    _targetLines(_owner.getTargetKeys())
{}

scene::INode::Type TargetLineNode::getNodeType() const
{
    return Type::EntityConnection;
}

const AABB& TargetLineNode::localAABB() const
{
    return _aabb;
}

void TargetLineNode::renderSolid(RenderableCollector& collector, const VolumeTest& volume) const
{
    renderWireframe(collector, volume);
}

void TargetLineNode::renderWireframe(RenderableCollector& collector, const VolumeTest& volume) const
{
    // If the owner is hidden, the lines are hidden too
    if (!_targetLines.hasTargets() || !_owner.visible()) return;

    collector.SetState(_owner.getWireShader(), RenderableCollector::eWireframeOnly);
	collector.SetState(_owner.getWireShader(), RenderableCollector::eFullMaterials);

	_targetLines.render(collector, volume, getOwnerPosition());
}

std::size_t TargetLineNode::getHighlightFlags()
{
    // We don't need to return highlighting, since the render system will use 
    // the result of the parent entity node
    return Highlight::NoHighlight;
}

const Vector3& TargetLineNode::getOwnerPosition() const
{
	const AABB& bounds = _owner.worldAABB();

	if (bounds.isValid())
    {
		return bounds.getOrigin();
	}

	return _owner.localToWorld().t().getVector3();
}

}
